@@ -1,3 +1,18 @@
+remove_text <- function(x) {
+  # Colors are problematic because a slight change in color will lead to test 
+  # failing -- this helper function removes them.
+  x$colorscale <- x$colorscale[[1]]
+  # Text is problematic because it is sensitive to precision because has numbers in it
+  x$text <- length(x$text)
+
+  x
+}
+
+replace_text <- function(x) {
+  x$data <- lapply(x$data, remove_text)
+  x
+}
+
 
 # modified from testhat expect_equal_to_reference
 expect_ihm_equal_to_reference <- function(object, file, ..., info = NULL) {
@@ -11,10 +26,10 @@ expect_ihm_equal_to_reference <- function(object, file, ..., info = NULL) {
   } else {
     reference <- readRDS(file)
     
-    objectsub <- object$x[c("data","layout")]
-    referencesub <- reference$x[c("data","layout")]
+    objectsub <- replace_text(object$x[c("data","layout")])
+    referencesub <- replace_text(reference$x[c("data","layout")])
     
-    comp <- testthat::compare(objectsub, referencesub, ...)
+    comp <- testthat::compare(objectsub, referencesub, tolerance = 0.1, ...)
     expect(
       comp$equal,
       sprintf("Not equal to %s.\n%s", lab_exp, comp$message),
